==> maxdb-source-7_5_00_34.zip: V75_00_34/MaxDB_ORG/sys/src/SAPDB/KernelCommon/ParameterNames/KernelParam_SharedSQL.hpp <==
/*!
  @file     KernelParam_SharedSQL.hpp
  @author   DirkT
  @ingroup  SharedSQL
  @brief    Mapping for configuration parameter names used by SharedSQL
  @see            

\if EMIT_LICENCE
    ========== licence begin  GPL
    Copyright (c) 2000-2005 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end

\endif
*/

#ifndef KERNELPARAM_SHAREDSQL_HPP
#define KERNELPARAM_SHAREDSQL_HPP

/// cserv name of the configuration parameter COMMANDCACHESIZE
#define KERNELPARAM_SHAREDSQL_YESNO                     (SAPDB_UTF8 *)"SHAREDSQL"

/// cserv name of the configuration parameter COMMANDCACHESIZE
#define KERNELPARAM_SHAREDSQL_COMMANDCACHESIZE          (SAPDB_UTF8 *)"SHAREDSQL_COMMANDCACHESIZE"

/// cserv name of the configuration parameter EXPECTEDSTATEMENTCOUNT
#define KERNELPARAM_SHAREDSQL_EXPECTEDSTATEMENTCOUNT    (SAPDB_UTF8 *)"SHAREDSQL_EXPECTEDSTATEMENTCOUNT"


#endif // KERNELPARAM_SHAREDSQLL_HPP

==> maxdb-source-7_6_00_37.zip: V76_00_37/MaxDB_ORG/sys/src/SAPDB/KernelCommon/ParameterNames/KernelParam_SharedSQL.hpp <==
/*!
  @file     KernelParam_SharedSQL.hpp
  @author   DirkT
  @ingroup  SharedSQL
  @brief    Mapping for configuration parameter names used by SharedSQL
  @see            

\if EMIT_LICENCE
    ========== licence begin  GPL
    Copyright (c) 2000-2005 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end

\endif
*/

#ifndef KERNELPARAM_SHAREDSQL_HPP
#define KERNELPARAM_SHAREDSQL_HPP

/// cserv name of the configuration parameter SHAREDSQL
#define KERNELPARAM_SHAREDSQL                           (SAPDB_UTF8 *)"SHAREDSQL"

/// cserv name of the configuration parameter COMMANDCACHESIZE
#define KERNELPARAM_SHAREDSQL_COMMANDCACHESIZE          (SAPDB_UTF8 *)"SHAREDSQL_COMMANDCACHESIZE"

/// cserv name of the configuration parameter EXPECTEDSTATEMENTCOUNT
#define KERNELPARAM_SHAREDSQL_EXPECTEDSTATEMENTCOUNT    (SAPDB_UTF8 *)"SHAREDSQL_EXPECTEDSTATEMENTCOUNT"


#endif // KERNELPARAM_SHAREDSQLL_HPP
